Struct ZwlrDataControlManagerV1
pub struct ZwlrDataControlManagerV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
manager to control data devices
This interface is a manager that allows creating per-seat data device controls.
This interface has no events.
Implementations
impl ZwlrDataControlManagerV1
impl ZwlrDataControlManagerV1
pub fn create_data_source<U, D>(
&self,
qh: &QueueHandle<D>,
udata: U,
) -> ZwlrDataControlSourceV1
pub fn create_data_source<U, D>( &self, qh: &QueueHandle<D>, udata: U, ) -> ZwlrDataControlSourceV1
create a new data source
Create a new data source.
pub fn get_data_device<U, D>(
&self,
seat: &WlSeat,
qh: &QueueHandle<D>,
udata: U,
) -> ZwlrDataControlDeviceV1
pub fn get_data_device<U, D>( &self, seat: &WlSeat, qh: &QueueHandle<D>, udata: U, ) -> ZwlrDataControlDeviceV1
get a data device for a seat
Create a data device that can be used to manage a seat’s selection.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the manager
All objects created by the manager will still remain valid, until their appropriate destroy request has been called.